@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Mojo::Base -base;
 use Module::Load qw/load/;
@@ -45,7 +45,7 @@ WebService::UK::Parliament - Query the UK Parliament API
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -58,13 +58,12 @@ Version 0.01
 	my $members = $factory->members();
 
 	my $local = $members->getLocationConstituencySearch({
-		searchText => $local_town,
-		take => 1,
+		searchText => $green_town,
+		take => 326,
 	});
 		
 	...
 
-
 =head1 DESCRIPTION
 
 Query the UK Parliament API via their OpenAPI definition. 
@@ -73,29 +72,88 @@ See L<https://developer.parliament.uk/> for the full documentation.
 
 They have no operationId so they're generated using the method + path minus params and slashes, as an example /api/Location/Constituency/{id} becomes getLocationConstituency.
 
-
 =head1 METHODS
 
 =head2 bills
 
+An API which retrieves Members data.
+
+	$factory->bills;
+
+=cut
+
 =head2 commonsVotes
 
+An API that allows querying of Commons Votes data.
+
+	$factory->commonsVotes;
+
+=cut
+
 =head2 erskinMay
 
+An API that allows querying of Erskine May data.
+
+	$factory->erskinMay;
+
+=cut
+	
 =head2 lordsVotes
 
+An API that allows querying of Lords Votes data.
+
+	$factory->lordsVotes;
+
+=cut
+
 =head2 members
 
+An API which retrieves Members data.
+
+	$factory->members;
+
+=cut
+
 =head2 now
 
+Get data from the annunciator system.
+
+	$factory->now;
+
+=cut
+
 =head2 oralQuestions
 
+An API that allows querying all tabled oral and written questions, and motions for the House of Commons.
+
+	$factory->oralQuestions;
+
+=cut
+
 =head2 statutoryInstruments
 
+An API exposing details of the various types of Statutory Instruments laid before Parliament.
+
+	$factory->statutoryInstruments;
+
+=cut
+
 =head2 treaties
 
+An API exposing details of the treaties laid before Parliament.
+
+	$factory->treaties;
+
+=cut
+
 =head2 writtenQuestions
 
+Data around written questions and answers, as well as written ministerial statements.
+
+	$factory->writtenQuestions;
+
+=cut
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
@@ -135,7 +193,7 @@ L<https://metacpan.org/release/WebService-UK-Parliament>
 
 =head1 LICENSE AND COPYRIGHT
 
-A ticehurst bathroom experience
+The first ticehurst bathroom experience
 
 This software is Copyright (c) 2022 by LNATION.
 
